@@ -1,11 +1,18 @@
 //! Builder and objects relating to function and method arguments.
 
-use std::convert::{TryFrom, TryInto};
+use std::{
+    convert::{TryFrom, TryInto},
+    ffi::CString,
+    ptr,
+};
 
 use super::{
     enums::DataType,
     execution_data::ExecutionData,
-    types::zval::{IntoZval, Zval},
+    types::{
+        zval::{IntoZvalDyn, Zval},
+        ZendType,
+    },
 };
 
 use crate::{
@@ -22,12 +29,13 @@ use crate::{
 /// Represents an argument to a function.
 #[derive(Debug, Clone)]
 pub struct Arg<'a> {
-    pub(crate) name: String,
-    pub(crate) _type: DataType,
-    pub(crate) as_ref: bool,
-    pub(crate) allow_null: bool,
-    pub(crate) default_value: Option<String>,
-    pub(crate) zval: Option<&'a Zval>,
+    name: String,
+    _type: DataType,
+    as_ref: bool,
+    allow_null: bool,
+    variadic: bool,
+    default_value: Option<String>,
+    zval: Option<&'a Zval>,
 }
 
 impl<'a> Arg<'a> {
@@ -43,6 +51,7 @@ impl<'a> Arg<'a> {
             _type,
             as_ref: false,
             allow_null: false,
+            variadic: false,
             default_value: None,
             zval: None,
         }
@@ -55,6 +64,12 @@ impl<'a> Arg<'a> {
         self
     }
 
+    /// Sets the argument as variadic.
+    pub fn is_variadic(mut self) -> Self {
+        self.variadic = true;
+        self
+    }
+
     /// Sets the argument as nullable.
     pub fn allow_null(mut self) -> Self {
         self.allow_null = true;
@@ -94,9 +109,26 @@ impl<'a> Arg<'a> {
     /// # Parameters
     ///
     /// * `params` - A list of parameters to call the function with.
-    pub fn try_call(&self, params: Vec<&dyn IntoZval>) -> Result<Zval> {
+    pub fn try_call(&self, params: Vec<&dyn IntoZvalDyn>) -> Result<Zval> {
         self.zval().ok_or(Error::Callable)?.try_call(params)
     }
+
+    /// Returns the internal PHP argument info.
+    pub(crate) fn as_arg_info(&self) -> Result<ArgInfo> {
+        Ok(ArgInfo {
+            name: CString::new(self.name.as_str())?.into_raw(),
+            type_: ZendType::empty_from_type(
+                self._type,
+                self.as_ref,
+                self.variadic,
+                self.allow_null,
+            ),
+            default_value: match &self.default_value {
+                Some(val) => CString::new(val.as_str())?.into_raw(),
+                None => ptr::null(),
+            },
+        })
+    }
 }
 
 impl From<Arg<'_>> for _zend_expected_type {
@@ -127,12 +159,12 @@ pub type ArgInfo = zend_internal_arg_info;
 pub struct ArgParser<'a, 'arg, 'zval> {
     args: Vec<&'arg mut Arg<'zval>>,
     min_num_args: Option<u32>,
-    execute_data: &'a mut ExecutionData,
+    execute_data: &'a ExecutionData,
 }
 
 impl<'a, 'arg, 'zval> ArgParser<'a, 'arg, 'zval> {
     /// Builds a new function argument parser.
-    pub fn new(execute_data: &'a mut ExecutionData) -> Self {
+    pub fn new(execute_data: &'a ExecutionData) -> Self {
         ArgParser {
             args: vec![],
             min_num_args: None,
