@@ -1,5 +1,9 @@
 //! Objects relating to PHP and the Zend engine.
 
+#[cfg(any(docs, feature = "alloc"))]
+#[cfg_attr(docs, doc(cfg(feature = "alloc")))]
+pub mod alloc;
+
 pub mod args;
 pub mod class;
 pub mod constants;
