@@ -38,37 +38,43 @@ pub unsafe trait Pack: Clone {
     ///
     /// # Safety
     ///
-    /// This is an unsafe function. There is no way to tell if the data passed from the PHP
-    /// function is indeed the correct format. Exercise caution when using the `unpack` functions.
-    /// In fact, even when used correctly, the results can differ depending on the platform and the
-    /// size of each type on the platform. Consult the [`pack`](https://www.php.net/manual/en/function.pack.php)
-    /// function documentation for more details.
+    /// There is no way to tell if the data stored in the string is actually of the given type.
+    /// The results of this function can also differ from platform-to-platform due to the different
+    /// representation of some types on different platforms. Consult the [`pack`] function
+    /// documentation for more details.
     ///
     /// # Parameters
     ///
     /// * `s` - The Zend string containing the binary data.
-    unsafe fn unpack_into(s: &zend_string) -> Vec<Self>;
+    ///
+    /// [`pack`]: https://www.php.net/manual/en/function.pack.php
+    fn unpack_into(s: &zend_string) -> Vec<Self>;
 }
 
 /// Implements the [`Pack`] trait for a given type.
-/// The first argument is the type and the second argument is the factor of size difference between
-/// the given type and an 8-bit integer e.g. impl Unpack for i32, factor = 4 => 4 * 8 = 32
 macro_rules! pack_impl {
+    ($t: ty) => {
+        pack_impl!($t, <$t>::BITS);
+    };
+
     ($t: ty, $d: expr) => {
         unsafe impl Pack for $t {
             fn pack_into(vec: Vec<Self>) -> *mut zend_string {
-                let len = vec.len() * $d;
+                let len = vec.len() * ($d as usize / 8);
                 let ptr = Box::into_raw(vec.into_boxed_slice());
                 unsafe { ext_php_rs_zend_string_init(ptr as *mut i8, len as _, false) }
             }
 
-            unsafe fn unpack_into(s: &zend_string) -> Vec<Self> {
-                let len = s.len / $d;
+            fn unpack_into(s: &zend_string) -> Vec<Self> {
+                let bytes = ($d / 8) as u64;
+                let len = (s.len as u64) / bytes;
                 let mut result = Vec::with_capacity(len as _);
                 let ptr = s.val.as_ptr() as *const $t;
 
+                // SAFETY: We calculate the length of memory that we can legally read based on the
+                // side of the type, therefore we never read outside the memory we should.
                 for i in 0..len {
-                    result.push(*ptr.offset(i as _));
+                    result.push(unsafe { *ptr.offset(i as _) });
                 }
 
                 result
@@ -77,17 +83,20 @@ macro_rules! pack_impl {
     };
 }
 
-pack_impl!(u8, 1);
-pack_impl!(i8, 1);
+pack_impl!(u8);
+pack_impl!(i8);
 
-pack_impl!(u16, 2);
-pack_impl!(i16, 2);
+pack_impl!(u16);
+pack_impl!(i16);
 
-pack_impl!(u32, 4);
-pack_impl!(i32, 4);
+pack_impl!(u32);
+pack_impl!(i32);
 
-pack_impl!(u64, 8);
-pack_impl!(i64, 8);
+pack_impl!(u64);
+pack_impl!(i64);
 
-pack_impl!(f32, 4);
-pack_impl!(f64, 8);
+pack_impl!(isize);
+pack_impl!(usize);
+
+pack_impl!(f32, 32);
+pack_impl!(f64, 64);
